@@ -1,7 +1,7 @@
 import logging
 
 logging.basicConfig(
-    format="%(asctime)s : %(levelname)s : %(message)s", level=logging.DEBUG
+    format="%(asctime)s : %(levelname)s : %(message)s", level=logging.INFO
 )
 from .hpc.mpi.primitives import stop, begin, skip, MASTER as ROOT, mprint as print
 
